@@ -6,7 +6,7 @@ Creating dict's for consistent type conversion.
 import numpy as np
 import ctypes as ct
 
-# SF-fmt, SF-typ,  np,        ct,  struc
+# SF-fmt, SF-typ,  np,        ct,      struc,  description
 table = [ \
   [    1,    0,    np.int8,   ct.c_byte, 'b', 'BYTE'        ],
   [    2,    6,    np.str_,   ct.c_char, 'c', 'CHAR'        ],
@@ -15,7 +15,7 @@ table = [ \
   [    5,    2, np.float32,  ct.c_float, 'f', 'IEEE_FLOAT'  ],
   [    6,    3, np.float64, ct.c_double, 'd', 'IEEE_DOUBLE' ],
   [    7,    5,    np.bool,   ct.c_bool, '?', 'LOGICAL'     ],
-  [    8, None,       None,        None,  '', 'CHAR_REAL'   ], 
+  [    8, None,       None,        None,  '', 'CHAR_REAL'   ],
   [    9,   12,  np.uint16, ct.c_uint16, 'H', 'U_SHORT'     ],
   [   10, None,       None,        None,  '', 'IBM_REAL'    ], 
   [   11, None,       None,        None,  '', 'IBM_DOUBLE'  ], 
@@ -25,25 +25,29 @@ table = [ \
   [   15,   14,  np.uint64, ct.c_uint64, 'Q', 'U_LONGLONG'  ],
 ]
 
+# CHAR length for string variables
 fmt2len = {2: 1, 1794: 8, 3842: 16, 7938: 32, 12034: 48, 16130: 64, 18178: 72}
 
 typ_tab   = list(zip(*table))
 
+# Mapping formats
 fmt2typ   = dict( zip(typ_tab[0], typ_tab[1]) )
 fmt2np    = dict( zip(typ_tab[0], typ_tab[2]) )
 fmt2ct    = dict( zip(typ_tab[0], typ_tab[3]) )
 fmt2struc = dict( zip(typ_tab[0], typ_tab[4]) )
+fmt2descr = dict( zip(typ_tab[0], typ_tab[5]) )
 typ2np    = dict( zip(typ_tab[1], typ_tab[2]) )
+typ2descr = dict( zip(typ_tab[1], typ_tab[5]) )
 
 # /usr/ads/codes
 #  objects
-obj_name = {1: 'Diagnostic', 2: 'List', 3: 'Device', 4: 'Param_Set', \
-            5: 'Map_Func', 6: 'Signal Group', 7: 'Signal', 8: 'Time Base', \
-            9: 'SF_List', 10: 'Algorithm', 11: 'Update_Set', \
-            12: 'Loc_Timer', 13: 'Area Base', 14: 'Qualifier', \
-            15: 'ModObj', 16: 'Map_Extd', 17: 'Resource', 18: 'ADDRLEN'}
+obj_name = {1 : 'Diagnostic', 2: 'List', 3: 'Device', 4: 'ParamSet', \
+            5 : 'MapFunc', 6: 'SignalGroup', 7: 'Signal', 8: 'TimeBase', \
+            9 : 'SFList', 10: 'Algorithm', 11: 'UpdateSet', \
+            12: 'LocTimer', 13: 'AreaBase', 14: 'Qualifier', \
+            15: 'ModObj', 16: 'MapExtd', 17: 'Resource', 18: 'ADDRLEN'}
 #  calibration
-cal_type = {0: 'NoCalib', 1: 'LinCalib', 2: 'LookUp-Tab', 3: 'extCalib'}
+cal_type = {0: 'NoCalib', 1: 'LinCalib', 2: 'LookUpTab', 3: 'extCalib'}
 
 #  timebases
 tbtype_d = { \
@@ -52,7 +56,7 @@ tbtype_d = { \
 #  addrsizes
 addrsizes = { 0: 1, 1: 1024, 2: 4096, 3: 8192}
 
-#  dimensions
+#  physics units
 unit_d = { \
   0:None, 1:'kg', 2:'m', 3:'V', 4:'A', 5:'mV', 6:'eV', 7:'J', 8:'s', 9:'min', 10:'h', \
   11:'Celsius', 12:'pm', 13:'msec', 14:'1/V', 15:'K', 16:'degree', 17:'keV', 18:'cm', \
