@@ -1,3 +1,5 @@
+import numpy as np
+
 def to_byt(str_or_byt):
     """
     Converts a plain string to a byte string (python2/3 compatibility)
@@ -19,3 +21,11 @@ def to_str(str_or_byt, strip=True):
         return str_out.strip()
     else:
         return str_out
+
+
+def to_small_endian(var):
+
+    var = np.array(var)
+    if var.dtype.byteorder == '>':
+        var = var.newbyteorder().byteswap(inplace=True)
+    return var
