@@ -371,8 +371,8 @@ class WW:
             if ndata == 0:
                 logger.error('No data for par_nam %s', par_name)
                 return
-            if ndata < nitem:
-                data = np.zeros(nitem, dtype=sfdics.typ2np[sf_dtype])
+#            if ndata < nitem:
+#                data = np.zeros(nitem, dtype=sfdics.typ2np[sf_dtype])
             error   = ct.c_int32(0)
             pset    = ct.c_char_p(set_name)
             par     = ct.c_char_p(par_name)
